@@ -1,3 +1,4 @@
+import collections
 import json
 
 import bokeh.plotting
@@ -8,12 +9,12 @@ from ..units import formatter_for_unit
 
 
 class TimeSeriesPlotMixin:
-    def get_history_plot(self, benchmark):
+    def get_history_plot(self, benchmark, run):
         history = self._get_history(benchmark)
         if history:
             return json.dumps(
                 bokeh.embed.json_item(
-                    time_series_plot(history, benchmark["id"]),
+                    time_series_plot(history, benchmark, run),
                     "plot-history",
                 )
             )
@@ -69,7 +70,7 @@ def _simple_source(data, unit):
     points_formated, units_formatted = [], set()
 
     for *values, point in data:
-        cases.append("-".join(values))
+        cases.append(values)
         points.append(point)
         formatted = unit_fmt(float(point), unit)
         means.append(formatted)
@@ -85,6 +86,12 @@ def _simple_source(data, unit):
     if axis_unit == unit:
         axis_unit = get_display_unit(unit)
 
+    # remove redundant tags from labels
+    len_cases = len(cases)
+    counts = collections.Counter([tag for case in cases for tag in case])
+    stripped = [[tag for tag in case if counts[tag] != len_cases] for case in cases]
+    cases = ["-".join(tags) for tags in stripped]
+
     source_data = dict(x=cases, y=points, means=means)
     return bokeh.models.ColumnDataSource(data=source_data), axis_unit
 
@@ -181,9 +188,15 @@ def _source(
     return bokeh.models.ColumnDataSource(data=source_data)
 
 
-def time_series_plot(history, benchmark_id, height=250, width=1000):
+def time_series_plot(history, benchmark, run, height=250, width=1000):
     unit = history[0]["unit"]
-    current = [h for h in history if h["benchmark_id"] == benchmark_id]
+    current = [
+        {
+            "mean": benchmark["stats"]["mean"],
+            "message": run["commit"]["message"],
+            "timestamp": run["commit"]["timestamp"],
+        }
+    ]
     with_dist = [h for h in history if h["distribution_mean"]]
     formatted, axis_unit = _should_format(history, unit)
 
