@@ -1,13 +1,12 @@
-import importlib.util
 import json
 import os
-import sys
 import time
 import urllib.parse
 
 import click
 import requests
 import yaml
+from _pytest.pathlib import import_path
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
 
@@ -143,13 +142,4 @@ def register_benchmarks(directory=None):
                     or filename.endswith("benchmark.py")
                     or filename.endswith("benchmarks.py")
                 ):
-                    import_module(directory, filename)
-
-
-def import_module(directory, filename):
-    module_name = filename.split(".")[0]
-    file_path = os.path.join(directory, filename)
-    spec = importlib.util.spec_from_file_location(module_name, file_path)
-    module = importlib.util.module_from_spec(spec)
-    sys.modules[module_name] = module
-    spec.loader.exec_module(module)
+                    import_path(f"{directory}/{filename}")
